@@ -45,13 +45,23 @@ def trace_http_request(method, url, json_data):
 def trace_http_response(json_data):
     """
     Log the given json response
-    :param url:
     :param json_data:
     :return:
     """
     if _trace_http:
         _append_http_trace("< json: {}".format(json.dumps(json_data)))
 
+def trace_http_response_raw(resp):
+    """
+    Log the given json response
+    :param resp:
+    :return:
+    """
+    if _trace_http:
+        _append_http_trace("< raw: status={}".format(resp.status_code))
+        if resp.status_code >= 300:
+            _append_http_trace("< raw: {}".format(str(resp)))
+
 
 def gethostname():
     try:
@@ -133,7 +143,7 @@ def generate_config(polled):
     if "artifacts" in polled and polled["artifacts"] is not None:
         job_config["artifacts"] = {}
         for item in polled["artifacts"]:
-            for element in ["name", "when", "paths", "reports", "expire_in"]:
+            for element in ["name", "when", "paths", "reports", "expire_in", "exclude"]:
                 if element in item:
                     value = item.get(element)
                     if value is not None:
