@@ -22,7 +22,7 @@ from .consts import NAME, VERSION
 from unidecode import unidecode
 
 
-def get_variable(job, name, default=None):
+def get_variable(job, *names, default=None):
     """
     Get a named variable from a job
     :param job:
@@ -31,8 +31,9 @@ def get_variable(job, name, default=None):
     :return:
     """
     for var in job["variables"]:
-        if var["key"] == name:
-            return var["value"]
+        for name in names:
+            if var["key"] == name:
+                return var["value"]
     return default
 
 
@@ -63,7 +64,17 @@ def archive(trace, config, jobname, tempdir, build_folder, success):
         if "paths" not in job_config["artifacts"]:
             return None
 
+        excludes = []
+        excludepatts = job_config["artifacts"].get("exclude", [])
+        for item in excludepatts:
+            if os.sep != '/':
+                item = item.replace("/", os.sep)
+            excludepatt = os.path.join(build_folder, item)
+            excludes.extend(glob.glob(excludepatt, recursive=True))
+
         trace.writeline("\nFinding artifacts...")
+        if excludes:
+            trace.writeline("\nExclude {} artifacts".format(len(excludes)))
 
         paths = job_config["artifacts"]["paths"]
         zipname = "archive.zip"
@@ -79,8 +90,11 @@ def archive(trace, config, jobname, tempdir, build_folder, success):
                 if os.sep != '/':
                     item = item.replace("/", os.sep)
                 localpatt = os.path.join(build_folder, item)
-                matches = glob.glob(localpatt)
+                matches = glob.glob(localpatt, recursive=True)
+
                 for include in matches:
+                    if include in excludes:
+                        continue
                     relpath = os.path.relpath(include, build_folder)
                     if os.path.isfile(include):
                         trace.writeline(".. match {}".format(include))
@@ -207,7 +221,7 @@ def run(runner, job, docker):
         trace_checkoutput(trace, ["git", "clone", git["repo_url"], build_dir], cwd=tempdir)
 
         # checkout the ref to build
-        trace_checkoutput(trace, ["git", "checkout", "-f", get_variable(job, "CI_COMMIT_REF")], cwd=build_dir_abs)
+        trace_checkoutput(trace, ["git", "checkout", "-f", get_variable(job, "CI_COMMIT_SHA", "CI_COMMIT_REF")], cwd=build_dir_abs)
 
         end_log_section(trace, "git")
 
